
% #Copyright belongs to Umich Optoelectronic Components and Materials Group (OCM)#
% #Please acknowledge us for using it:)#

%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%%
clear all

% constants
hbar=6.625e-34/(2*pi); %kg-m^2/s
m0=9.109e-31; %kg
eps0=8.85e-14; %F/cm
q=1.602e-19; %C
c=3e10; %cm/s

% wavelength range, total steps
lambda=400:5:900;
steps=2000; 

if exist('int')==0
    int=100;   %light intensity, in mW/cm2 (one sun)
end
 
 
%% load index files
% files must have points at ends of data range
 
%~~~Anode and Cathode~~~
QtzNK_F = importdata('qtz_tab.txt');
ITONK_F = importdata('ITO_tab.txt');
AlNK_F = importdata('al_tab.txt');
AgNK_F = importdata('ag_tab.txt');
AuNK_F = importdata('au_tab.txt');

%~~~Buffers~~~
MoO3_F = importdata('moo3_tab.txt');
PEDOT_F = importdata('pedot_tab.txt');

ZnONK_F = importdata('ZnO_tab.txt');
PTCBI_F = importdata('PTCBI_tab.txt');
BCP_F = importdata('bcp_tab.txt');
C60_BCP_F= importdata ('c60_bcp_1_1_tab.txt');

%~~~Donor & Accpetor~~~
DBPC70NK_F = importdata('DBP_C70_thin_tab_1to10.txt');
C70_F = importdata('c70_tab.txt');
C60_F=importdata('C60_tab.txt');

%~~~Spectrum~~~
AMG_F=importdata('AMGcorr.txt'); %AM 1.5G, units of photon/nm^2-s-nm


%% material n-k index profiles

QtzNK = interp1(QtzNK_F(:,1),QtzNK_F(:,2),lambda)+i*interp1(QtzNK_F(:,1),QtzNK_F(:,3),lambda);
ITONK = (interp1(ITONK_F(:,1),ITONK_F(:,2),lambda))+i*interp1(ITONK_F(:,1),ITONK_F(:,3),lambda);
AlNK = interp1(AlNK_F(:,1),AlNK_F(:,2),lambda)+i*interp1(AlNK_F(:,1),AlNK_F(:,3),lambda);
AgNK = interp1(AgNK_F(:,1),AgNK_F(:,2),lambda)+i*interp1(AgNK_F(:,1),AgNK_F(:,3),lambda);
AuNK = interp1(AuNK_F(:,1),AuNK_F(:,2),lambda)+i*interp1(AuNK_F(:,1),AuNK_F(:,3),lambda);

MoO3NK = interp1(MoO3_F(:,1),MoO3_F(:,2),lambda,'spline')+i*interp1(MoO3_F(:,1),MoO3_F(:,3),lambda,'spline');
PEDOTNK = interp1(PEDOT_F(:,1),PEDOT_F(:,2),lambda,'spline')+i*interp1(PEDOT_F(:,1),PEDOT_F(:,3),lambda,'spline');

ZnONK = interp1(ZnONK_F(:,1),ZnONK_F(:,2),lambda)+i*interp1(ZnONK_F(:,1),ZnONK_F(:,3),lambda);
PTCBINK = interp1(PTCBI_F(:,1),PTCBI_F(:,2),lambda,'spline')+i*interp1(PTCBI_F(:,1),PTCBI_F(:,3),lambda,'spline');
BCPNK = interp1(BCP_F(:,1),BCP_F(:,2),lambda,'spline')+i*interp1(BCP_F(:,1),BCP_F(:,3),lambda,'spline');
C60BCPNK = interp1(C60_BCP_F(:,1),C60_BCP_F(:,2),lambda)+i*interp1(C60_BCP_F(:,1),C60_BCP_F(:,3),lambda);

DBPC70NK = interp1(DBPC70NK_F(:,1),DBPC70NK_F(:,2),lambda)+i*interp1(DBPC70NK_F(:,1),DBPC70NK_F(:,3),lambda); 
C60NK = interp1(C60_F(:,1),C60_F(:,2),lambda,'spline')+i*interp1(C60_F(:,1),C60_F(:,3),lambda,'spline');
C70NK = interp1(C70_F(:,1),C70_F(:,2),lambda,'spline')+i*interp1(C70_F(:,1),C70_F(:,3),lambda,'spline');

AMG = interp1(AMG_F(:,1),AMG_F(:,2),lambda,'spline');



%% define structure 
%films grown on Quartz (can be changed in function "calc_efield")             
nair=ones(1,length(lambda));

index(1,:)=ITONK;width(1)=100;  %width: nm
index(2,:)=DBPC70NK;width(2)=50;
index(3,:)=nair;
%end structure


%% profile of layers thickness for the device

layerpos(1)=0;   
for k=1:length(width)
    layerpos(k+1)=layerpos(k)+width(k);
end

pos=linspace(0,layerpos(length(layerpos)),steps); % position defined by steps


%% Efield, transmission and reflection calculation based on transfer matrix
[Efield,Qj,Ttot,Rtot]=calc_efield(lambda,index,width,steps,QtzNK);


%% Plots 

% Plot Ttot
figure(1)
   title('Transmission','FontSize',16)
     plot(lambda,Ttot,'LineWidth',3) 
     axis([min(lambda) max(lambda) 0 1])
     ylabel('Tranmission','FontSize',16);
     xlabel('Lambda (nm)','FontSize',16);

% Plot Rtot
figure(2)
   title('Reflection','FontSize',16)
     plot(lambda,Rtot,'LineWidth',3) 
     axis([min(lambda) max(lambda) 0 1])
     ylabel('Reflection','FontSize',16);
     xlabel('Lambda (nm)','FontSize',16);

     
% Plot Qj    
figure(3)  % color plot of absorbed optical power distribution
     axes('FontSize',16)
        clf
        imagesc(lambda, pos, Qj);
        title('Qj','FontSize',16)
        xlabel('lambda (nm)','FontSize',16)
        ylabel('position (nm)','FontSize',16)
        axis([min(lambda) max(lambda) layerpos(1) layerpos(length(width)+1)])
        colormap(jet)
        colorbar
        set(gca,'YDir','normal') 
     
        
 %% End   
     
     
     
     
     




