function [Efield,Qj,Ttot,Rtot]=calc_efield(lambda,index,width,steps,QtzNK);

hbar=6.625e-34/(2*pi); %kg-m^2/s
m0=9.109e-31; %kg
eps0=8.85e-14; %F/cm
q=1.602e-19; %C
c=3e10; %cm/s

nair=ones(1,length(lambda));
sub=QtzNK; %substrate material

angle=0*pi/180; %normal incident angle

%% start calculations (Please refer to paper: J. Appl. Phys., Vol. 93, No. 7, 1 April 2003)

% calculate S from air to layer j
T_glass = abs(4*cos(angle)*sub./(cos(angle)*nair+sub).^2);
R_glass = abs((cos(angle)*nair-sub)./(cos(angle)*nair+sub)).^2;

q0=sub*cos(angle);
    
q1=sqrt(index(1,:).^2-((sub).^2)*(sin(angle))^2);

r01=(q0-q1)./(q0+q1);
t01=2*q0./(q0+q1);


S(1,1,:)=1./t01;
S(1,2,:)=r01./t01;
S(2,1,:)=S(1,2,:);
S(2,2,:)=S(1,1,:);
S;

I(1,1,:)=1./t01;
I(1,2,:)=r01./t01;
I(2,1,:)=S(1,2,:);
I(2,2,:)=S(1,1,:);
I;

b1=2*pi*q1./lambda;

L(1,1,:)=exp(-i*b1*width(1));
L(1,2,:)=0;
L(2,1,:)=0;
L(2,2,:)=exp(i*b1*width(1));
L;

for j=1:length(width)
             
    qj=sqrt(index(j,:).^2-(nair.^2)*(sin(angle))^2);
    qk=sqrt(index(j+1,:).^2-(nair.^2)*(sin(angle))^2);
        
    bj(j,:)=2*pi*qj./lambda;
        
    Lj(1,1,:)=exp(-i*bj(j,:)*width(j));
    Lj(1,2,:)=0;
    Lj(2,1,:)=0;
    Lj(2,2,:)=exp(i*bj(j,:)*width(j));
        
    rjk=(qj-qk)./(qj+qk);
    tjk=2*qj./(qj+qk);
    
    Ijk(1,1,:)=1./tjk;
    Ijk(1,2,:)=rjk./tjk;
    Ijk(2,1,:)=Ijk(1,2,:);
    Ijk(2,2,:)=Ijk(1,1,:);
    
    Sleft11(j,:)=S(1,1,:);
    Sleft12(j,:)=S(1,2,:);
    S;
    Lj;
    for k=1:length(lambda)
        S(:,:,k)=S(:,:,k)*Lj(:,:,k)*Ijk(:,:,k);
    end
    Ijk;
end


% calculate S from right side to layer j
S=Ijk;

for j=1:length(width)-1
    
    v=length(width)-j;
             
    qj=sqrt(index(v,:).^2-(nair.^2)*(sin(angle)).^2);
    qk=sqrt(index(v+1,:).^2-(nair.^2)*(sin(angle)).^2);
        
    bj2=2*pi*qk./lambda;
        
    Lj(1,1,:)=exp(-i*bj2*width(v+1));
    Lj(1,2,:)=0;
    Lj(2,1,:)=0;
    Lj(2,2,:)=exp(i*bj2*width(v+1));
    
    rjk=(qj-qk)./(qj+qk);
    tjk=2*qj./(qj+qk);
    rjk;
    
    Ijk(1,1,:)=1./tjk;
    Ijk(1,2,:)=rjk./tjk;
    Ijk(2,1,:)=Ijk(1,2,:);
    Ijk(2,2,:)=Ijk(1,1,:);
    
    Sright11(v+1,:)=S(1,1,:);
    Sright21(v+1,:)=S(2,1,:);
    
    for k=1:length(lambda)
        S(:,:,k)=Ijk(:,:,k)*Lj(:,:,k)*S(:,:,k);
    end
end

Sright11(1,:)=S(1,1,:);
Sright21(1,:)=S(2,1,:);
pos=0;
layerpos(1)=0;
for k=1:length(width)
    layerpos(k+1)=layerpos(k)+width(k);
end

for k=1:length(lambda)
        S(:,:,k)=I(:,:,k)*L(:,:,k)*S(:,:,k);
end

%% Calculation of Ttot, Rtot
T=(1./squeeze(S(1,1,:))).*conj(1./squeeze(S(1,1,:))).*abs(nair./sub)';%t
R=(squeeze(S(2,1,:))./squeeze(S(1,1,:))).*conj(squeeze(S(2,1,:))./squeeze(S(1,1,:)));%r

%Total transmission and reflection considering the Quartz substrate
Ttot=(T.*T_glass')./(nair'+R.*R_glass');
Rtot=(R+R_glass')./(nair'+R.*R_glass');
% [Ttot Rtot 1-Ttot-Rtot]; 


%% calculation of Efield, Qj
pos=linspace(0,layerpos(length(layerpos)),steps);

for k=1:steps
    for j=1:length(width)
        if pos(k)<layerpos(j+1)
            % j points to current layer
            break;
        end
    end
    dj=width(j);
    x=pos(k)-layerpos(j);
    tpos=(1./Sleft11(j,:))./(1+(Sleft12(j,:).*Sright21(j,:)./(Sleft11(j,:).*Sright11(j,:))).*exp(i*2*bj(j,:)*dj));
    tneg=tpos.*exp(i*2*dj*bj(j,:)).*Sright21(j,:)./Sright11(j,:);
    Efield(k,:)=(abs(tpos.*exp(i*bj(j,:)*x)+tneg.*exp(-i*bj(j,:)*x))).^2;  % Efield districution
    Qj(k,:)=4*pi*imag(index(j,:)).*real(index(j,:)).*Efield(k,:)./lambda;  % absorbed optical power distribution
end